<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tdm="http://www.quest.com/toad-data-modeler" xmlns:msxsl="urn:schemas-microsoft-com:xslt">
	<tdm:description>Output contains Relationship name, parent entity and child entity names and parent and child attribute names. You can change ListSeparator as well as AttributeSeparator parameters. ListSeparator separates CSV values, AttributeSeparator separates attribute names (relationship created using PK of multiple columns.) </tdm:description>
	<tdm:caption>Relationships (CSV)</tdm:caption>
	<tdm:default-filename>relationships</tdm:default-filename>
	<tdm:default-suffix>csv</tdm:default-suffix>
	<tdm:db-platforms>
		<tdm:db-platform>all</tdm:db-platform>
	</tdm:db-platforms>
	<!--*************************************************************-->
	<!--JScript function to handle quotation marks and aphostrophes.-->
	<!--*************************************************************-->
	<msxsl:script language="JScript" implements-prefix="tdm">
		function closeInApostrophes( nodelist ) {
		var text = nodelist.nextNode().text;
		return( '"' + text.replace( /\"/g, '""' ) + '"' );
		}
	</msxsl:script>

	<xsl:output method="text" />
	<!--*************************************************************-->
	<!--Parameters definition. Both parameter values will appear in GUI-->
	<!--*************************************************************-->
	<xsl:param name="ListSeparator" select="," />
	<xsl:param name="AttributeSeparator" select=";" />
	<xsl:template match="/">
		<!--*************************************************************-->
		<!--iterate all Model/Relationships/Relation nodes-->
		<!--*************************************************************-->
		<xsl:for-each select="Model/Relationships/Relation">
			<!--*************************************************************-->
			<!--First row will contain column headers-->
			<!--*************************************************************-->
			<xsl:if test="position() = 1">
				<xsl:text>Relationship Name</xsl:text>
				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Parent Entity</xsl:text>
				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Child Entity</xsl:text>
				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Parent Attribute</xsl:text>
				<xsl:value-of select="$ListSeparator" />
				<xsl:text>Child Attribute</xsl:text>
				<xsl:text>&#10;</xsl:text>
			</xsl:if>
			<!--*************************************************************-->
			<!--Processing XML data-->
			<!--*************************************************************-->
			<xsl:value-of select="tdm:closeInApostrophes(Name)" />
			<xsl:value-of select="$ListSeparator" />
			<xsl:value-of select="tdm:closeInApostrophes(O1/Name)" />
			<xsl:value-of select="$ListSeparator" />
			<xsl:value-of select="tdm:closeInApostrophes(O2/Name)" />
			<xsl:value-of select="$ListSeparator" />
			<!--*************************************************************-->
			<!--Relationships can be created using more than one column.-->
			<!--If only one column is used, generate simple output...-->
			<!--*************************************************************-->
			<xsl:choose>
				<xsl:when test="count(ForeignKeys/ForeignKey) = 1">
					<xsl:value-of select="tdm:closeInApostrophes(ForeignKeys/ForeignKey/ParentAttribute/Name)" />
					<xsl:value-of select="$ListSeparator" />
					<xsl:value-of select="tdm:closeInApostrophes(ForeignKeys/ForeignKey/ChildAttribute/Name)" />
				</xsl:when>
				<!--*************************************************************-->
				<!--...if multiple columns are used, write column names separated -->
				<!--by AttributeSeparator defined as Parameter.-->
				<!--*************************************************************-->
				<xsl:otherwise>
					<xsl:for-each select="ForeignKeys/ForeignKey">
						<xsl:value-of select="ParentAttribute/Name" />
						<xsl:if test="position() != last()">
							<xsl:value-of select="$AttributeSeparator" />
						</xsl:if>
					</xsl:for-each>
					<xsl:value-of select="$ListSeparator" />
					<xsl:for-each select="ForeignKeys/ForeignKey">
						<xsl:value-of select="ChildAttribute/Name" />
						<xsl:if test="position() != last()">
							<xsl:value-of select="$AttributeSeparator" />
						</xsl:if>
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:text>&#10;</xsl:text>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>
